﻿using System;
using Xamarin.Forms;

#if __UNIFIED__
using Foundation;
using UIKit;
using CoreGraphics;
#else
using nint = System.Int32;
using nuint = System.Int32;
using nfloat = System.Single;

using MonoTouch.Foundation;
using MonoTouch.UIKit;

using CGRect = System.Drawing.RectangleF;
using CGPoint = System.Drawing.PointF;
using CGSize = System.Drawing.SizeF;
#endif

namespace Syncfusion.SfCalendar.XForms.iOS
{
	public static class CalendarHelper
	{
		#region Date Converters
		public static NSDate DateTimeToNSDate(this DateTime date)
		{
			if (date.Kind == DateTimeKind.Unspecified)
				date = DateTime.SpecifyKind (date, DateTimeKind.Local);
			else if (date.Kind == DateTimeKind.Utc)
				date = DateTime.SpecifyKind(date, DateTimeKind.Utc);
			return (NSDate) date;
		}
		public static NSDate DateTimeToNSDateUTC(this DateTime date)
		{
			if (date.Kind == DateTimeKind.Unspecified)
			{
				DateTime tempDate = new DateTime(date.Year, date.Month, date.Day, 0, 0, 0);
				date = DateTime.SpecifyKind(tempDate, DateTimeKind.Local);
			}
			return (NSDate)date;
		}
		public static DateTime NSDateToDateTime(this NSDate nsDate) {
			if (nsDate == null) {
				return new DateTime();
			} else {
				DateTime reference = new DateTime (2001, 1, 1, 0, 0, 0);
				return (DateTime)reference.AddSeconds (nsDate.SecondsSinceReferenceDate);
			}
		}
		internal static DateTime NSDateToDateTimeMonthLoaded(this NSDate nsDate)
		{
			if (nsDate == null) return new DateTime();

			NSCalendar cal = NSCalendar.CurrentCalendar;
			int year = (int)cal.GetComponentFromDate(NSCalendarUnit.Year, nsDate);
			int month = (int)cal.GetComponentFromDate(NSCalendarUnit.Month, nsDate);
			int day = (int)cal.GetComponentFromDate(NSCalendarUnit.Day, nsDate);
			int hour = (int)cal.GetComponentFromDate(NSCalendarUnit.Hour, nsDate);
			int minute = (int)cal.GetComponentFromDate(NSCalendarUnit.Minute, nsDate);
			int second = (int)cal.GetComponentFromDate(NSCalendarUnit.Second, nsDate);
			int nanosecond = (int)cal.GetComponentFromDate(NSCalendarUnit.Nanosecond, nsDate);

			int millisecond = (nanosecond / 1000000);

			return new DateTime(year, month, day, hour, minute, second, millisecond, DateTimeKind.Local);
		}
		#endregion

		#region Color Converter

		public static UIColor ColorToUIColor(Xamarin.Forms.Color color) {
			UIColor nativeColor  = UIColor.FromRGBA ((float)color.R, (float)color.G, (float)color.B,(float)color.A);
			return nativeColor;
		}
		public static Color UIColorToColor(UIColor color) {
			nfloat a,b,c,d;
			color.GetRGBA (out a, out b, out c, out d);
			Color nativeColor = Color.FromRgba(a,b,c,d);
			return nativeColor;
		}
		#endregion

	}
}

